{% load i18n admin_urls unfold %}

<div {% if not is_popup %}id="submit-row"{% endif %} class="relative lg:sticky lg:bottom-0 z-40">
    <div class="backdrop-blur-xs bg-white/80 rounded-b-default pb-4 px-4 dark:bg-base-900/80 lg:border-t lg:border-base-200 relative lg:scrollable-top lg:py-0 dark:border-base-800">
        <div class="flex flex-col-reverse gap-3 items-center mx-auto lg:flex-row-reverse container lg:h-[64px]">
            {% block submit-row %}
                {% if show_save %}
                    {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name="_save" class="w-full lg:w-auto" %}
                        {% trans "Save" %}
                    {% endcomponent %}
                {% endif %}

                {% for action in actions_submit_line %}
                    {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name=action.attrs.name|default:action.action_name variant="default" class="w-full lg:w-auto" attrs=action.attrs %}
                        {% if action.icon %}
                            <span class="material-symbols-outlined">
                                {{ action.icon }}
                            </span>
                        {% endif %}

                        {{ action.description }}
                    {% endcomponent %}
                {% endfor %}

                {% if show_save_and_continue %}
                    {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name="_continue" variant="default" class="w-full lg:w-auto" %}
                        {% if can_change %}
                            {% trans "Save and continue editing" %}
                        {% else %}
                            {% trans "Save and view" %}
                        {% endif %}
                    {% endcomponent %}
                {% endif %}

                {% if show_save_and_add_another %}
                    {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name="_addanother" variant="default" class="w-full lg:w-auto" %}
                        {% trans "Save and add another" %}
                    {% endcomponent %}
                {% endif %}

                {% if show_save_as_new %}
                    {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name="_saveasnew" variant="default" class="w-full lg:w-auto" %}
                        {% trans "Save as new" %}
                    {% endcomponent %}
                {% endif %}

                <div class="flex flex-col gap-3 mr-auto w-full lg:flex-row lg:w-auto">
                    {% if show_close or adminform.model_admin.change_form_show_cancel_button %}
                        {% url opts|admin_urlname:'changelist' as changelist_url %}
                        {% add_preserved_filters changelist_url as link %}

                        {% component "unfold/components/button.html" with href=link variant="default" class="w-full lg:w-auto"%}
                            {% trans "Close" %}
                        {% endcomponent %}
                    {% endif %}

                    {% if show_delete_link and original %}
                        {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
                        {% add_preserved_filters delete_url as link %}

                        {% component "unfold/components/button.html" with href=delete_url variant="danger" class="mr-auto w-full lg:w-auto" %}
                            {% trans "Delete" %} {{ opts.verbose_name }}
                        {% endcomponent %}
                    {% endif %}
                </div>
            {% endblock %}
        </div>
    </div>
</div>
