{% load i18n static unfold %}

<div class="flex flex-row gap-4 items-center ml-auto">
    {% if environment %}
        {% include "unfold/helpers/label.html" with text=environment.0 type=environment.1 %}
    {% endif %}

    {% action_list %}

    {% if nav_global_side %}
        {{ nav_global_side }}
    {% endif %}
</div>
