<fieldset {% if fieldset.css_id %}id="{{ fieldset.css_id }}"{% endif %} class="fieldset group flex flex-col grow rounded-default border-base-200 shadow-xs aligned border p-3 relative dark:border-base-800 {% if fieldset.css_class %} {{ fieldset.css_class }}{% endif %}" {{ fieldset.flat_attrs }}>
    {% if legend %}
        <div class="border-b border-base-200 font-semibold {% if 'form-horizontal' not in form_class %}mb-4{% endif %} -mx-3 pb-3 px-3 text-[15px] text-important dark:border-base-800">
            {{ legend|safe }}
        </div>
    {% endif %}

    <div class="flex flex-col {% if 'form-horizontal' not in form_class %} gap-5{% endif %}">
        {{ fields|safe }}
    </div>
</fieldset>
