{% if item.badge %}
    <span class="font-semibold h-[18px] leading-[18px] ml-2 px-1 relative rounded-xs text-center text-[11px] whitespace-nowrap uppercase min-w-[18px]
                 {% if item.badge_style == "solid" %}
                     text-white text-shadow-xs
                 {% endif %}
                 {% if item.badge_variant == "info" %}
                     {% if item.badge_style == "solid" %}
                         bg-blue-500
                     {% else %}
                         bg-blue-100 text-blue-700 dark:bg-blue-500/20 dark:text-blue-400
                     {% endif %}
                 {% elif item.badge_variant == "success" %}
                     {% if item.badge_style == "solid" %}
                         bg-green-500
                     {% else %}
                         bg-green-100 text-green-700 dark:bg-green-500/20 dark:text-green-400
                     {% endif %}
                 {% elif item.badge_variant == "warning" %}
                     {% if item.badge_style == "solid" %}
                         bg-orange-500
                     {% else %}
                         bg-orange-100 text-orange-700 dark:bg-orange-500/20 dark:text-orange-400
                     {% endif %}
                 {% elif item.badge_variant == "primary" %}
                     {% if item.badge_style == "solid" %}
                         bg-primary-500
                     {% else %}
                         bg-primary-100 text-primary-700 dark:bg-primary-500/20 dark:text-primary-400
                     {% endif %}
                 {% else %}
                     {% if item.badge_style == "solid" %}
                         bg-red-500
                     {% else %}
                         bg-red-100 text-red-700 dark:bg-red-500/20 dark:text-red-400
                     {% endif %}
                 {% endif %}
                ">
        {% if item.badge_callback %}
            {{ item.badge_callback }}
        {% else %}
            {{ item.badge }}
        {% endif %}
    </span>
{% endif %}
