{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
    {% trans "After you've created a user, you’ll be able to edit more user options." as message %}
    {% include "unfold/helpers/messages/info.html" with message=message %}
{% endblock %}
