{% load unfold unfold_list i18n %}

<div class="flex flex-row gap-4">
    <a {% if cl.page_num != 1 %}href="{% infinite_paginator_url cl cl.page_num|add:-1 %}"{% endif %} class="{% if cl.page_num != 1 %}hover:text-primary-600 dark:hover:text-primary-500{% else %}text-subtle{% endif %}">
        {% trans "Previous" %}
    </a>

    <a {% if cl.result_list|length == cl.paginator.per_page %}href="{% infinite_paginator_url cl cl.page_num|add:1 %}"{% endif %} class="{% if cl.result_list|length and cl.result_list|length == cl.paginator.per_page %}hover:text-primary-600 dark:hover:text-primary-500{% else %}text-subtle{% endif %}">
        {% trans "Next" %}
    </a>
</div>
