{% for name, value in widget.attrs.items %}
    {% if name == "selected" %}
        <option value="{{ widget.value|stringformat:'s' }}"{% include "django/forms/widgets/attrs.html" %}>{{ widget.label }}</option>
    {% endif %}
{% endfor %}
