{% if error_count > 0 %}
    <span class="bg-red-500 inline-flex font-semibold items-center justify-center leading-none rounded-full w-4 h-4 text-white relative text-center text-[11px] whitespace-nowrap uppercase">
        {{ error_count }}
    </span>
{% endif %}
