{% load i18n unfold %}

<div {% if not is_popup %}id="submit-row"{% endif %} class="relative lg:sticky lg:bottom-0 z-40">
    <div class="backdrop-blur-xs bg-white/80 rounded-b-default pb-4 px-4 dark:bg-base-900/80 {% if not is_popup %}lg:border-t lg:border-base-200 relative lg:scrollable-top lg:py-0 dark:border-base-800{% endif %}">
        <div class="flex flex-col-reverse gap-3 items-center mx-auto lg:flex-row-reverse container lg:h-[64px]">
            {% if not revert_disabled %}
                {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name="_save" extra_attrs=onclick_attrib class="w-full lg:w-auto" %}
                    {% trans "Revert" %}
                {% endcomponent %}
            {% endif %}

            {% if change_history %}
                {% component "unfold/components/button.html" with submit=1 form=opts.model_name|add:"_form" name="_change_history" extra_attrs=onclick_attrib class="w-full lg:w-auto" %}
                    {% trans "Change History" %}
                {% endcomponent %}
            {% endif %}

            {% component "unfold/components/button.html" with href=history_url variant="default" class="mr-auto w-full lg:w-auto" %}
                {% trans 'Close' %}
            {% endcomponent %}
        </div>
    </div>
</div>
